@@ -1,23 +1,24 @@
 
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_TARNAME "am-utils"
-#define PACKAGE_VERSION "6.1b5pre"
-#define PACKAGE_STRING "am-utils 6.1b5pre"
-#define PACKAGE_BUGREPORT "am-utils@am-utils.org"
+#define PACKAGE_VERSION "6.2a1"
+#define PACKAGE_STRING "am-utils 6.2a1"
+#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "freebsd4.10"
+#define HOST_OS "freebsd4.11"
 #define HOST_OS_NAME "freebsd4"
-#define HOST_OS_VERSION "4.10"
+#define HOST_OS_VERSION "4.11"
 #define HOST_ARCH "i386"
-#define HOST_NAME "a-freebsd410.fsl.cs.sunysb.edu"
+#define DISTRO_NAME "none"
+#define HOST_NAME "a-freebsd411.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Thu Jan 13 17:14:31 EST 2005"
+#define CONFIG_DATE "Fri Oct  7 15:50:26 EDT 2005"
 #define PACKAGE_NAME "am-utils"
-#define PACKAGE_VERSION "6.1b5pre"
-#define PACKAGE_BUGREPORT "am-utils@am-utils.org"
+#define PACKAGE_VERSION "6.2a1"
+#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define PACKAGE "am-utils"
-#define VERSION "6.1b5pre"
+#define VERSION "6.2a1"
 #define DEBUG 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
@@ -29,10 +30,9 @@
 #define HAVE_INTTYPES_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_DLFCN_H 1
-#define HOST_HEADER_VERSION "4.10"
+#define HOST_HEADER_VERSION "4.11"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
-#define HAVE_ALLOCA 1
 #define HAVE_UNISTD_H 1
 #define HAVE_FORK 1
 #define HAVE_VFORK 1
@@ -57,6 +57,7 @@
 #define HAVE_GETMNTINFO 1
 #define HAVE_GETPAGESIZE 1
 #define HAVE_GETTIMEOFDAY 1
+#define HAVE_HSTRERROR 1
 #define HAVE_MADVISE 1
 #define HAVE_MEMCMP 1
 #define HAVE_MEMCPY 1
@@ -77,11 +78,14 @@
 #define HAVE_SIGNAL 1
 #define HAVE_SIGSUSPEND 1
 #define HAVE_SOCKET 1
+#define HAVE_STATFS 1
+#define HAVE_STRCASECMP 1
 #define HAVE_STRCHR 1
 #define HAVE_STRCSPN 1
-#define HAVE_STRCASECMP 1
 #define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
+#define HAVE_STRLCAT 1
+#define HAVE_STRLCPY 1
 #define HAVE_STRSPN 1
 #define HAVE_STRSTR 1
 #define HAVE_SVC_GETREQ 1
@@ -97,6 +101,8 @@
 #define HAVE_STRCASECMP 1
 #define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
+#define HAVE_STRLCAT 1
+#define HAVE_STRLCPY 1
 #define HAVE_STRSTR 1
 #define HAVE_UALARM 1
 #define HAVE_XDR_ATTRSTAT 1
@@ -200,6 +206,7 @@
 #define HAVE_IFADDRS_H 1
 #define HAVE_GRP_H 1
 #define HAVE_LIBGEN_H 1
+#define HAVE_LIMITS_H 1
 #define HAVE_MALLOC_H 1
 #define HAVE_MEMORY_H 1
 #define HAVE_NDBM_H 1
@@ -228,6 +235,7 @@
 #define HAVE_FS_NFS3 1
 #define GETGROUPS_T gid_t
 #define RETSIGTYPE void
+#define rpcvers_t unsigned long
 #define HAVE_FHANDLE 1
 #define MTYPE_TYPE char *
 #define MTYPE_PRINTF_TYPE "%s"
@@ -241,6 +249,7 @@
 #define ufs_args_t struct ufs_args
 #define XDRPROC_T_TYPE xdrproc_t
 #define voidp void *
+#define HAVE_C99_VARARGS_MACROS 1
 #define HAVE_EXTERN_SYS_ERRLIST 1
 #define HAVE_EXTERN_OPTARG 1
 #define HAVE_EXTERN_CLNT_SPCREATEERROR 1
@@ -258,8 +267,11 @@
 #define HAVE_EXTERN_SBRK 1
 #define HAVE_EXTERN_SETEUID 1
 #define HAVE_EXTERN_SETITIMER 1
+#define HAVE_EXTERN_SLEEP 1
 #define HAVE_EXTERN_STRCASECMP 1
 #define HAVE_EXTERN_STRDUP 1
+#define HAVE_EXTERN_STRLCAT 1
+#define HAVE_EXTERN_STRLCPY 1
 #define HAVE_EXTERN_STRSTR 1
 #define HAVE_EXTERN_UALARM 1
 #define HAVE_EXTERN_USLEEP 1
@@ -282,7 +294,9 @@
 #define HAVE_UFS_ARGS_T_FSPEC 1
 #define HAVE_STRUCT_STATFS_F_FSTYPENAME 1
 #define HAVE_NFS_ARGS_T_ACDIRMIN 1
+#define HAVE_NFS_ARGS_T_ACDIRMAX 1
 #define HAVE_NFS_ARGS_T_ACREGMIN 1
+#define HAVE_NFS_ARGS_T_ACREGMAX 1
 #define HAVE_NFS_ARGS_T_FHSIZE 1
 #define HAVE_NFS_ARGS_T_PROTO 1
 #define HAVE_NFS_ARGS_T_SOTYPE 1
@@ -291,6 +305,8 @@
 #define HAVE_STRUCT_IFADDRS_IFA_NEXT 1
 #define HAVE_STRUCT_SOCKADDR_SA_LEN 1
 #define HAVE_MAP_FILE 1
+#define HAVE_MAP_SUN 1
+#define HAVE_MAP_EXEC 1
 #define HAVE_MAP_NIS 1
 #define HAVE_MAP_PASSWD 1
 #define HAVE_MAP_UNION 1
@@ -304,7 +320,6 @@
 #define HAVE_AMU_FS_DIRECT 1
 #define HAVE_AMU_FS_TOPLVL 1
 #define HAVE_AMU_FS_ERROR 1
-#define HAVE_AMU_FS_INHERIT 1
 #define HAVE_AMU_FS_PROGRAM 1
 #define HAVE_AMU_FS_LINK 1
 #define HAVE_AMU_FS_LINKX 1
@@ -328,6 +343,7 @@
 #define MNTTAB_TYPE_MFS "mfs"
 #define MNTTAB_TYPE_UNIONFS "unionfs"
 #define MNT2_GEN_OPT_ASYNC 0x40
+#define MNT2_GEN_OPT_FORCE 0x80000
 #define MNT2_GEN_OPT_IGNORE 0x800000
 #define MNT2_GEN_OPT_NODEV 0x10
 #define MNT2_GEN_OPT_NOEXEC 0x4
