@@ -620,7 +620,7 @@ case 25:
 break;
 case 26:
 #line 236 "../../fsinfo/fsi_gram.y"
-{ yyval.d = (disk_fs *) 0; }
+{ yyval.d = (disk_fs *) NULL; }
 break;
 case 27:
 #line 252 "../../fsinfo/fsi_gram.y"
